@@ -1,28 +1,52 @@
 from ._internal_utils import is_bpython
+from typing_extensions import Protocol
 
 
-class _Color:
+class _Renderable(Protocol):
+    def wrap_text(self, text: str) -> str:
+        pass
+
+    def __eq__(self, other: object) -> bool:
+        pass
+
+
+class _Color(_Renderable):
     def __init__(self, color_code: int, bright: bool = False) -> None:
         self.color_code = str(color_code)
         self.intensity = '1' if bright else '0'
 
     def wrap_text(self, text: str) -> str:
-        if is_bpython():
-            colored_text = '\033[%sm%s\033[0m' % (self.color_code, text)
-            if self.intensity == '0':
-                return colored_text
-            else:
-                return '\033[1m' + colored_text
-        else:
+        if not is_bpython():
             return '\033[%s;%sm%s\033[0m' % (self.intensity, self.color_code, text)
 
-    def __eq__(self, other: '_Color') -> bool:  # type: ignore
+        colored_text = '\033[%sm%s\033[0m' % (self.color_code, text)
+        if self.intensity == '0':
+            return colored_text
+        else:
+            return '\033[1m' + colored_text
+
+    def __eq__(self, other: object) -> bool:  # type: ignore
+        # __eq__ should work with any objects.
+        # https://mypy.readthedocs.io/en/stable/common_issues.html#incompatible-overrides
+        if not isinstance(other, _Color):
+            return False
+
         return self.color_code == other.color_code
 
     def __repr__(self):
         return '\033[%sm%s\033[0m' % (self.color_code, 'color')
 
 
+class _ColorDisabled(_Renderable):
+    def wrap_text(self, text: str) -> str:
+        return text
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, _ColorDisabled):
+            return True
+        return False
+
+
 COLORS = {
     'black': _Color(30),
     'bright black': _Color(30, True),
@@ -42,3 +66,4 @@ COLORS = {
     'white': _Color(37),
     'bright white': _Color(37, True),
 }
+COLOR_DISABLED = _ColorDisabled()
